@@ -1,5 +1,4 @@
-/* $Id: daemon.c 4064 2008-04-09 22:00:21Z rra $
- *
+/*
  * Replacement for a missing daemon.
  *
  * Provides the same functionality as the library function daemon for those
@@ -17,6 +16,17 @@
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 
+/*
+ * If we're running the test suite, rename daemon to avoid conflicts with the
+ * system version.  #undef it first because some systems may define it to
+ * another name.
+ */
+#if TESTING
+# undef daemon
+# define daemon test_daemon
+int test_daemon(int, int);
+#endif
+
 int
 daemon(int nochdir, int noclose)
 {
